@@ -11,25 +11,27 @@ def configuration(parent_package='', top_path=None):
         libraries.append('m')
 
     config.add_extension('ball_tree',
-                         sources=['ball_tree.c'],
+                         sources=['ball_tree.pyx'],
                          include_dirs=[numpy.get_include()],
                          libraries=libraries)
 
     config.add_extension('kd_tree',
-                         sources=['kd_tree.c'],
+                         sources=['kd_tree.pyx'],
                          include_dirs=[numpy.get_include()],
                          libraries=libraries)
 
     config.add_extension('dist_metrics',
-                         sources=['dist_metrics.c'],
+                         sources=['dist_metrics.pyx'],
                          include_dirs=[numpy.get_include(),
                                        os.path.join(numpy.get_include(),
                                                     'numpy')],
                          libraries=libraries)
 
     config.add_extension('typedefs',
-                         sources=['typedefs.c'],
+                         sources=['typedefs.pyx'],
                          include_dirs=[numpy.get_include()],
                          libraries=libraries)
 
+    config.add_subpackage('tests')
+
     return config
